==> jc-1.4.0.tar.gz: javax/swing/event/TableColumnModelEvent.h <==
// public class javax.swing.event.TableColumnModelEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class e29191d7a2770486 javax_swing_event_TableColumnModelEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TableColumnModelEvent_H_
#define _JC_javax_swing_event_TableColumnModelEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_TableColumnModel$object;

// Typedefs
typedef struct _jc_javax_swing_event_TableColumnModelEvent$sub_refs	_jc_javax_swing_event_TableColumnModelEvent$sub_refs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs	_jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$refs	_jc_javax_swing_event_TableColumnModelEvent$refs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$nonrefs	_jc_javax_swing_event_TableColumnModelEvent$nonrefs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$object	_jc_javax_swing_event_TableColumnModelEvent$object;

typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vmethods	_jc_javax_swing_event_TableColumnModelEvent$vmethods;
typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vtable	_jc_javax_swing_event_TableColumnModelEvent$vtable;
typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vtype	_jc_javax_swing_event_TableColumnModelEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_TableColumnModelEvent$method$_init$3a9f6a46956a60b3(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *, struct _jc_object *, jint, jint);

// Virtual methods
extern jint _jc_javax_swing_event_TableColumnModelEvent$method$getFromIndex$536fc4f5f110db46(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);
extern jint _jc_javax_swing_event_TableColumnModelEvent$method$getToIndex$5a94aa070f30a048(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);
extern void _jc_javax_swing_event_TableColumnModelEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$getFromIndex$536fc4f5f110db46;
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$getToIndex$5a94aa070f30a048;
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TableColumnModelEvent$vmethods {
	jint	(*getFromIndex$536fc4f5f110db46)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);
	jint	(*getToIndex$5a94aa070f30a048)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_TableColumnModelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TableColumnModelEvent$vmethods	javax_swing_event_TableColumnModelEvent;
};

// Vtype
struct _jc_javax_swing_event_TableColumnModelEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TableColumnModelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TableColumnModelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TableColumnModelEvent$refs {
    _jc_javax_swing_event_TableColumnModelEvent$sub_refs	javax_swing_event_TableColumnModelEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs {
	jint	fromIndex;
	jint	toIndex;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TableColumnModelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs	javax_swing_event_TableColumnModelEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TableColumnModelEvent$object {
	_jc_javax_swing_event_TableColumnModelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TableColumnModelEvent$vtype	*vtype;
	_jc_javax_swing_event_TableColumnModelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TableColumnModelEvent$vtype _jc_javax_swing_event_TableColumnModelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TableColumnModelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TableColumnModelEvent$class_object;

#endif	/* _JC_javax_swing_event_TableColumnModelEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/TableColumnModelEvent.h <==
// public class javax.swing.event.TableColumnModelEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class e29191d7a2770486 javax_swing_event_TableColumnModelEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TableColumnModelEvent_H_
#define _JC_javax_swing_event_TableColumnModelEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_table_TableColumnModel$object;

// Typedefs
typedef struct _jc_javax_swing_event_TableColumnModelEvent$sub_refs	_jc_javax_swing_event_TableColumnModelEvent$sub_refs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs	_jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$refs	_jc_javax_swing_event_TableColumnModelEvent$refs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$nonrefs	_jc_javax_swing_event_TableColumnModelEvent$nonrefs;
typedef struct _jc_javax_swing_event_TableColumnModelEvent$object	_jc_javax_swing_event_TableColumnModelEvent$object;

typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vmethods	_jc_javax_swing_event_TableColumnModelEvent$vmethods;
typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vtable	_jc_javax_swing_event_TableColumnModelEvent$vtable;
typedef const struct _jc_javax_swing_event_TableColumnModelEvent$vtype	_jc_javax_swing_event_TableColumnModelEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_TableColumnModelEvent$method$_init$3a9f6a46956a60b3(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_event_TableColumnModelEvent$method$getFromIndex$536fc4f5f110db46(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_TableColumnModelEvent$method$getToIndex$5a94aa070f30a048(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TableColumnModelEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$getFromIndex$536fc4f5f110db46;
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$getToIndex$5a94aa070f30a048;
extern _jc_method _jc_javax_swing_event_TableColumnModelEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TableColumnModelEvent$vmethods {
	jint	(*getFromIndex$536fc4f5f110db46)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getToIndex$5a94aa070f30a048)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TableColumnModelEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_TableColumnModelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TableColumnModelEvent$vmethods	javax_swing_event_TableColumnModelEvent;
};

// Vtype
struct _jc_javax_swing_event_TableColumnModelEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TableColumnModelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TableColumnModelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TableColumnModelEvent$refs {
    _jc_javax_swing_event_TableColumnModelEvent$sub_refs	javax_swing_event_TableColumnModelEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs {
	jint	fromIndex;
	jint	toIndex;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TableColumnModelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TableColumnModelEvent$sub_nonrefs	javax_swing_event_TableColumnModelEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TableColumnModelEvent$object {
	_jc_javax_swing_event_TableColumnModelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TableColumnModelEvent$vtype	*vtype;
	_jc_javax_swing_event_TableColumnModelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TableColumnModelEvent$vtype _jc_javax_swing_event_TableColumnModelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TableColumnModelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TableColumnModelEvent$class_object;

#endif	/* _JC_javax_swing_event_TableColumnModelEvent_H_ */
